@@ -2,13 +2,13 @@
 using namespace Rcpp;
 
 /*
-  * codes in sdc_status:
-  * 0: possible suppression partner ("s")
-  * 1: primary suppression ("u")
-  * 2: secondary suppression ("x")
-  * 3: non-applicable ("z")
-  * 4: dummy-cells ("w")
-*/
+ * codes in sdc_status:
+ * 0: possible suppression partner ("s")
+ * 1: primary suppression ("u")
+ * 2: secondary suppression ("x")
+ * 3: non-applicable ("z")
+ * 4: dummy-cells ("w")
+ */
 IntegerVector sdcstatus_to_num(CharacterVector sdc_status) {
   IntegerVector result(sdc_status.size());
   for (int i = 0; i < sdc_status.size(); i++) {
@@ -156,10 +156,10 @@ List greedyMultDimSuppression(DataFrame dat, List indices, List subIndices, Inte
                   }
                 }
                 /*
-                  we have at least 1 observation in the current
-                  simple table but only a single suppressed cell and
-                  the number of dummy-cells (which should never be published) is 0
-                */
+                 we have at least 1 observation in the current
+                 simple table but only a single suppressed cell and
+                 the number of dummy-cells (which should never be published) is 0
+                 */
                 if ((nr_supps == 1) & (nr_dummycells == 0)) {
                   int nr_candidates = sum(is_candidate);
                   if (nr_candidates == 0) {
@@ -179,11 +179,11 @@ List greedyMultDimSuppression(DataFrame dat, List indices, List subIndices, Inte
                     }
 
                     /*
-                      Relaxation case
-                      In this case, it is not possible to find a pattern with only 's'-cells.
-                      we need to relax 'z' (code 3) cells to 's' (code 0) and try again.
-                      However, we do not allow z-cells that were initially "z"
-                    */
+                     Relaxation case
+                     In this case, it is not possible to find a pattern with only 's'-cells.
+                     we need to relax 'z' (code 3) cells to 's' (code 0) and try again.
+                     However, we do not allow z-cells that were initially "z"
+                     */
                     if (debug) {
                       Rcout << "we need to set 'z'-cells to 's'!" << std::endl;
                       Rcout << "the current subtable (debug_df):" << std::endl;
@@ -257,10 +257,10 @@ List greedyMultDimSuppression(DataFrame dat, List indices, List subIndices, Inte
                   cur_is_real_z = cur_is_real_z[is_candidate];
 
                   /*
-                    find the index with lowest weights but take the
-                    highest index if multiple obs exist!
-                    This helps to prevent suppressing marginal cells
-                  */
+                   find the index with lowest weights but take the
+                   highest index if multiple obs exist!
+                   This helps to prevent suppressing marginal cells
+                   */
                   double min_val = min(cur_weights);
                   IntegerVector v = seq(0, cur_weights.size() - 1);
                   IntegerVector tmpres = v[cur_weights == min_val];
@@ -280,7 +280,8 @@ List greedyMultDimSuppression(DataFrame dat, List indices, List subIndices, Inte
                       Named("id") = final_index,
                       Named("freq") = freq[final_index],
                       Named("weights") = weights[final_index],
-                      Named("sdcstatus_num") = sdcstatus_num[final_index]);
+                      Named("sdcstatus_num") = sdcstatus_num[final_index]
+                    );
                     print(df_supp);
                     R_FlushConsole();
                   }
@@ -334,10 +335,10 @@ List greedyMultDimSuppression(DataFrame dat, List indices, List subIndices, Inte
     } /* end for-loop (groups) */
 
     /*
-      check if we went through all subtables in all groups
-      without setting any 'z' cells to 's'.
-      In this case, we can stop the outer while-loop!
-    */
+     check if we went through all subtables in all groups
+     without setting any 'z' cells to 's'.
+     In this case, we can stop the outer while-loop!
+     */
     if ((override == false) & (final_ok == true)) {
       runInd = false;
     } else {
